FirstOrderRoot

Trait FirstOrderRoot 

pub trait FirstOrderRoot<V>
where Self: ElasticIV<V>, V: Tensor,
{ // Required method fn root( &self, applied_load: AppliedLoad, solver: impl FirstOrderRootFindingBlock<DeformationGradient, V, FirstPiolaKirchhoffStress, <Self as ElasticIV<V>>::Residual, FirstPiolaKirchhoffTangentStiffness, Self::TangentVu, Self::TangentUv, Self::TangentVv>, strategy: SolveStrategy, ) -> Result<(DeformationGradient, V), ConstitutiveError>; }
First-order root-finding methods for elastic solid constitutive models with internal variables.

Required Methods

fn root( &self, applied_load: AppliedLoad, solver: impl FirstOrderRootFindingBlock<DeformationGradient, V, FirstPiolaKirchhoffStress, <Self as ElasticIV<V>>::Residual, FirstPiolaKirchhoffTangentStiffness, Self::TangentVu, Self::TangentUv, Self::TangentVv>, strategy: SolveStrategy, ) -> Result<(DeformationGradient, V), ConstitutiveError>

Solve for the unknown components of the deformation gradient under an applied load.

\mathbf{P}(\mathbf{F}) - \boldsymbol{\lambda} - \mathbf{P}_0 = \mathbf{0}

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, V> FirstOrderRoot<V> for T
where T: ElasticIV<V>, V: Tensor,