ZerothOrderRoot

Trait ZerothOrderRoot 

pub trait ZerothOrderRoot<V>
where V: Tensor,
{ type Residuals; type Variables; // Required method fn root( &self, applied_load: AppliedLoad, solver: impl ZerothOrderRootFinding<Self::Residuals, Self::Variables>, ) -> Result<(DeformationGradient, V), ConstitutiveError>; }
Zeroth-order root-finding methods for elastic solid constitutive models with internal variables.

Required Associated Types

type Residuals

Type representing all residuals.

type Variables

Type representing all variables.

Required Methods

fn root( &self, applied_load: AppliedLoad, solver: impl ZerothOrderRootFinding<Self::Residuals, Self::Variables>, ) -> Result<(DeformationGradient, V), ConstitutiveError>

Solve for the unknown components of the deformation gradient under an applied load.

\mathbf{P}(\mathbf{F}) - \boldsymbol{\lambda} - \mathbf{P}_0 = \mathbf{0}

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors